lace.engine module
==================

.. currentmodule:: lace.engine

Class
-----
.. autoclass::
    Engine

.. autoproperty::
    Engine.shape
.. autoproperty::
    Engine.n_rows
.. autoproperty::
    Engine.n_cols
.. autoproperty::
    Engine.n_states
.. autoproperty::
    Engine.columns
.. autoproperty::
    Engine.index
.. autoproperty::
    Engine.ftypes

Methods
-------
.. autosummary::
    :toctree: generated/

    Engine.save
    Engine.ftype
    Engine.column_assignment
    Engine.row_assignments
    Engine.diagnostics
    Engine.append_rows
    Engine.update
    Engine.entropy
    Engine.logp
    Engine.inconsistency
    Engine.surprisal
    Engine.simulate
    Engine.draw
    Engine.predict
    Engine.impute
    Engine.depprob
    Engine.mi
    Engine.rowsim
    Engine.novelty
    Engine.pairwise_fn
    Engine.clustermap